import time
import visa

# IP address SMBV100B
ip_address = '127.0.0.1'

# Create visa connection
rm = visa.ResourceManager()
smw = rm.open_resource('TCPIP::' + ip_address + '::INSTR', write_termination=None)
smw.timeout = 10000

# Reset SMBV100A
smw.query('*RST; *OPC?')

# Configure Hardware in the Loop mode:
# 1. Set operation mode to 'Navigation'
smw.query(':SOUR1:BB:GNSS:TMOD NAV; *OPC?')

# 2. Set Postion to Remote control
smw.query(':SOUR1:BB:GNSS:REC:V1:POS HIL; *OPC?')

# 3. Enter system latency and interface type
smw.query(':SOUR1:BB:GNSS:REC:V1:HIL:SLAT 0.12; *OPC?')
smw.query(':SOUR1:BB:GNSS:REC:V1:HIL:ITYP SCPI; *OPC?')

# 4. Set initial position
smw.query(':SOUR1:BB:GNSS:REC:V1:LOC:COOR:DEC:WGS 0.0, 0.0, 10.0; *OPC?')

# 6. Switch on the GNSS simulation and the RF output.
smw.query(':SOUR1:BB:GNSS:STAT ON; *OPC?')
smw.query('OUTP:STAT 1; *OPC?')

time.sleep(40)
smw.write(':SOUR1:BB:GNSS:RT:REC:V1:HILP:MODE:A 41, 6378147, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0')
time.sleep(1)
smw.write(':SOUR1:BB:GNSS:RT:REC:V1:HILP:MODE:A 42, 6378147, 10, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0')
time.sleep(1)
smw.write(':SOUR1:BB:GNSS:RT:REC:V1:HILP:MODE:A 43, 6378147, 20, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0')
time.sleep(1)
smw.write(':SOUR1:BB:GNSS:RT:REC:V1:HILP:MODE:A 44, 6378147, 30, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0')
time.sleep(1)
smw.write(':SOUR1:BB:GNSS:RT:REC:V1:HILP:MODE:A 45, 6378147, 40, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0')
smw.close()
